@@ -1,5 +1,3 @@
-from __future__ import annotations
-
 
 import math
 
@@ -119,7 +117,7 @@ __global__ void find_breakpoint_position_nd(
 '''
 
 INTERVAL_MODULE = cupy.RawModule(
-    code=INTERVAL_KERNEL,
+    code=INTERVAL_KERNEL, options=('-std=c++11',),
     name_expressions=[
         'find_breakpoint_position_1d', 'find_breakpoint_position_nd'])
 
@@ -390,7 +388,7 @@ __global__ void integrate(
 """
 
 PPOLY_MODULE = cupy.RawModule(
-    code=PPOLY_KERNEL,
+    code=PPOLY_KERNEL, options=('-std=c++11',),
     name_expressions=(
         [f'eval_ppoly<{type_name}>' for type_name in TYPES] +
         [f'eval_ppoly_nd<{type_name}>' for type_name in TYPES] +
@@ -535,7 +533,7 @@ __global__ void eval_bpoly(
 """
 
 BPOLY_MODULE = cupy.RawModule(
-    code=BPOLY_KERNEL,
+    code=BPOLY_KERNEL, options=('-std=c++11',),
     name_expressions=(
         [f'eval_bpoly<{type_name}>' for type_name in TYPES]))
 
