@@ -1,5 +1,3 @@
-from __future__ import annotations
-
 import operator
 from math import pi
 import warnings
@@ -463,7 +461,7 @@ def freqz(b, a=1, worN=512, whole=False, plot=None, fs=2*pi,
                 # Move the first axis of h to the end.
                 h = cupy.moveaxis(h, 0, -1)
     else:
-        w = cupy.atleast_1d(worN).real
+        w = cupy.atleast_1d(worN)
         w = 2 * pi * w / fs
 
     if h is None:  # still need to compute using freqs w
@@ -568,7 +566,7 @@ def _validate_sos(sos):
     return sos, n_sections
 
 
-def freqz_sos(sos, worN=512, whole=False, fs=2*pi):
+def sosfreqz(sos, worN=512, whole=False, fs=2*pi):
     r"""
     Compute the frequency response of a digital filter in SOS format.
 
@@ -630,11 +628,6 @@ def freqz_sos(sos, worN=512, whole=False, fs=2*pi):
     return w, h
 
 
-def sosfreqz(sos, worN=512, whole=False, fs=2*pi):
-    """A legacy alias for freqz_sos."""
-    return freqz_sos(sos, worN, whole, fs)
-
-
 def _hz_to_erb(hz):
     """
     Utility for converting from frequency (Hz) to the
